# -*- coding: utf8 -*-

u"""
    Mathics: a general-purpose computer algebra system
    Copyright (C) 2011 Jan Pöschko

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation either version 3 of the License or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not see <http://www.gnu.org/licenses/>.
"""

# Character ranges of letters
letters = u'a-zA-Z\u00c0-\u00d6\u00d8-\u00f6\u00f8-\u0103\u0106\u0107\
\u010c-\u010f\u0112-\u0115\u011a-\u012d\u0131\u0141\u0142\u0147\u0148\
\u0150-\u0153\u0158-\u0161\u0164\u0165\u016e-\u0171\u017d\u017e\
\u0391-\u03a1\u03a3-\u03a9\u03b1-\u03c9\u03d1\u03d2\u03d5\u03d6\
\u03da-\u03e1\u03f0\u03f1\u03f5\u210a-\u210c\u2110-\u2113\u211b\u211c\
\u2128\u212c\u212d\u212f-\u2131\u2133-\u2138\uf6b2-\uf6b5\uf6b7\uf6b9\
\uf6ba-\uf6bc\uf6be\uf6bf\uf6c1-\uf700\uf730\uf731\uf770\uf772\uf773\
\uf776\uf779\uf77a\uf77d-\uf780\uf782-\uf78b\uf78d-\uf78f\uf790\
\uf793-\uf79a\uf79c-\uf7a2\uf7a4-\uf7bd\uf800-\uf833\ufb01\ufb02'

# Character ranges of letterlikes
letterlikes = u'\u0024\u00A1\u00A2\u00A3\u00A5\u00A7\u00A9\u00AB\u00AE\
\u00B0\u00B5\u00B6\u00B8\u00BB\u00BF\u02C7\u02D8\u2013\u2014\u2020\u2021\
\u2022\u2026\u2032\u2033\u2035\u2036\u2060\u20AC\u210F\u2122\u2127\u212B\
\u21B5\u2205\u221E\u221F\u2220\u2221\u2222\u22EE\u22EF\u22F0\u22F1\u2300\
\u2318\u231A\u23B4\u23B5\u2500\u2502\u25A0\u25A1\u25AA\u25AE\u25AF\u25B2\
\u25B3\u25BC\u25BD\u25C0\u25C6\u25C7\u25CB\u25CF\u25E6\u25FB\u25FC\u2605\
\u2639\u263A\u2660\u2661\u2662\u2663\u266D\u266E\u266F\u2736\uF3A0\uF3B8\
\uF3B9\uF527\uF528\uF720\uF721\uF722\uF723\uF725\uF749\uF74A\uF74D\uF74E\
\uF74F\uF750\uF751\uF752\uF753\uF754\uF755\uF756\uF757\uF760\uF763\uF766\
\uF768\uF769\uF76A\uF76B\uF76C\uF7D4\uF800\uF801\uF802\uF803\uF804\uF805\
\uF806\uF807\uF808\uF809\uF80A\uF80B\uF80C\uF80D\uF80E\uF80F\uF810\uF811\
\uF812\uF813\uF814\uF815\uF816\uF817\uF818\uF819\uF81A\uF81B\uF81C\uF81D\
\uF81E\uF81F\uF820\uF821\uF822\uF823\uF824\uF825\uF826\uF827\uF828\uF829\
\uF82A\uF82B\uF82C\uF82D\uF82E\uF82F\uF830\uF831\uF832\uF833\uFE35\uFE36\
\uFE37\uFE38'

# All supported longname characters
named_characters = {
    'AAcute': u'\u00E1',
    'ABar': u'\u0101',
    'ACup': u'\u0103',
    'ADoubleDot': u'\u00E4',
    'AE': u'\u00E6',
    'AGrave': u'\u00E0',
    'AHat': u'\u00E2',
    'Aleph': u'\u2135',
    'AliasDelimiter': u'\uF764',
    'AliasIndicator': u'\uF768',
    'AlignmentMarker': u'\uF760',
    'Alpha': u'\u03B1',
    'AltKey': u'\uF7D1',
    'And': u'\u2227',
    'Angle': u'\u2220',
    'Angstrom': u'\u212B',
    'ARing': u'\u00E5',
    'AscendingEllipsis': u'\u22F0',
    'ATilde': u'\u00E3',
    'AutoLeftMatch': u'\uF3A8',
    'AutoOperand': u'\uF3AE',
    'AutoPlaceholder': u'\uF3A4',
    'AutoRightMatch': u'\uF3A9',
    'AutoSpace': u'\uF3AD',
    'Backslash': u'\u2216',
    'BeamedEighthNote': u'\u266B',
    'BeamedSixteenthNote': u'\u266C',
    'Because': u'\u2235',
    'Bet': u'\u2136',
    'Beta': u'\u03B2',
    'BlackBishop': u'\u265D',
    'BlackKing': u'\u265A',
    'BlackKnight': u'\u265E',
    'BlackPawn': u'\u265F',
    'BlackQueen': u'\u265B',
    'BlackRook': u'\u265C',
    'Breve': u'\u02D8',
    'Bullet': u'\u2022',
    'CAcute': u'\u0107',
    'CapitalAAcute': u'\u00C1',
    'CapitalABar': u'\u0100',
    'CapitalACup': u'\u0102',
    'CapitalADoubleDot': u'\u00C4',
    'CapitalAE': u'\u00C6',
    'CapitalAGrave': u'\u00C0',
    'CapitalAHat': u'\u00C2',
    'CapitalAlpha': u'\u0391',
    'CapitalARing': u'\u00C5',
    'CapitalATilde': u'\u00C3',
    'CapitalBeta': u'\u0392',
    'CapitalCAcute': u'\u0106',
    'CapitalCCedilla': u'\u00C7',
    'CapitalCHacek': u'\u010C',
    'CapitalChi': u'\u03A7',
    'CapitalDelta': u'\u0394',
    'CapitalDHacek': u'\u010E',
    'CapitalDifferentialD': u'\uF74B',
    'CapitalDigamma': u'\u03DC',
    'CapitalEAcute': u'\u00C9',
    'CapitalEBar': u'\u0112',
    'CapitalECup': u'\u0114',
    'CapitalEDoubleDot': u'\u00CB',
    'CapitalEGrave': u'\u00C8',
    'CapitalEHacek': u'\u011A',
    'CapitalEHat': u'\u00CA',
    'CapitalEpsilon': u'\u0395',
    'CapitalEta': u'\u0397',
    'CapitalEth': u'\u00D0',
    'CapitalGamma': u'\u0393',
    'CapitalIAcute': u'\u00CD',
    'CapitalICup': u'\u012C',
    'CapitalIDoubleDot': u'\u00CF',
    'CapitalIGrave': u'\u00CC',
    'CapitalIHat': u'\u00CE',
    'CapitalIota': u'\u0399',
    'CapitalKappa': u'\u039A',
    'CapitalKoppa': u'\u03DE',
    'CapitalLambda': u'\u039B',
    'CapitalLSlash': u'\u0141',
    'CapitalMu': u'\u039C',
    'CapitalNHacek': u'\u0147',
    'CapitalNTilde': u'\u00D1',
    'CapitalNu': u'\u039D',
    'CapitalOAcute': u'\u00D3',
    'CapitalODoubleAcute': u'\u0150',
    'CapitalODoubleDot': u'\u00D6',
    'CapitalOE': u'\u0152',
    'CapitalOGrave': u'\u00D2',
    'CapitalOHat': u'\u00D4',
    'CapitalOmega': u'\u03A9',
    'CapitalOmicron': u'\u039F',
    'CapitalOSlash': u'\u00D8',
    'CapitalOTilde': u'\u00D5',
    'CapitalPhi': u'\u03A6',
    'CapitalPi': u'\u03A0',
    'CapitalPsi': u'\u03A8',
    'CapitalRHacek': u'\u0158',
    'CapitalRho': u'\u03A1',
    'CapitalSampi': u'\u03E0',
    'CapitalSHacek': u'\u0160',
    'CapitalSigma': u'\u03A3',
    'CapitalStigma': u'\u03DA',
    'CapitalTau': u'\u03A4',
    'CapitalTHacek': u'\u0164',
    'CapitalTheta': u'\u0398',
    'CapitalThorn': u'\u00DE',
    'CapitalUAcute': u'\u00DA',
    'CapitalUDoubleAcute': u'\u0170',
    'CapitalUDoubleDot': u'\u00DC',
    'CapitalUGrave': u'\u00D9',
    'CapitalUHat': u'\u00DB',
    'CapitalUpsilon': u'\u03A5',
    'CapitalURing': u'\u016E',
    'CapitalXi': u'\u039E',
    'CapitalYAcute': u'\u00DD',
    'CapitalZeta': u'\u0396',
    'CapitalZHacek': u'\u017D',
    'Cap': u'\u2322',
    'CCedilla': u'\u00E7',
    'Cedilla': u'\u00B8',
    'CenterDot': u'\u00B7',
    'CenterEllipsis': u'\u22EF',
    'Cent': u'\u00A2',
    'CHacek': u'\u010D',
    'Checkmark': u'\u2713',
    'Chi': u'\u03C7',
    'CircleDot': u'\u2299',
    'CircleMinus': u'\u2296',
    'CirclePlus': u'\u2295',
    'CircleTimes': u'\u2297',
    'ClockwiseContourIntegral': u'\u2232',
    'CloseCurlyDoubleQuote': u'\u201D',
    'CloseCurlyQuote': u'\u2019',
    'CloverLeaf': u'\u2318',
    'ClubSuit': u'\u2663',
    'Colon': u'\u2236',
    'CommandKey': u'\uF76A',
    'Congruent': u'\u2261',
    'Conjugate': u'\uF3C8',
    'ConjugateTranspose': u'\uF3C9',
    'ConstantC': u'\uF7DA',
    'Continuation': u'\uF3B1',
    'ContourIntegral': u'\u222E',
    'ControlKey': u'\uF763',
    'Coproduct': u'\u2210',
    'Copyright': u'\u00A9',
    'CounterClockwiseContourIntegral': u'\u2233',
    'Cross': u'\uF4A0',
    'CupCap': u'\u224D',
    'Cup': u'\u2323',
    'CurlyCapitalUpsilon': u'\u03D2',
    'CurlyEpsilon': u'\u03B5',
    'CurlyKappa': u'\u03F0',
    'CurlyPhi': u'\u03C6',
    'CurlyPi': u'\u03D6',
    'CurlyRho': u'\u03F1',
    'CurlyTheta': u'\u03D1',
    'Currency': u'\u00A4',
    'Dagger': u'\u2020',
    'Dalet': u'\u2138',
    'Dash': u'\u2013',
    'Degree': u'\u00B0',
    'DeleteKey': u'\uF7D0',
    'Del': u'\u2207',
    'Delta': u'\u03B4',
    'DescendingEllipsis': u'\u22F1',
    'DHacek': u'\u010F',
    'Diameter': u'\u2300',
    'Diamond': u'\u22C4',
    'DiamondSuit': u'\u2662',
    'DifferenceDelta': u'\u2206',
    'DifferentialD': u'\uF74C',
    'Digamma': u'\u03DD',
    'DiscreteRatio': u'\uF4A4',
    'DiscreteShift': u'\uF4A3',
    'DiscretionaryHyphen': u'\u00AD',
    'DiscretionaryLineSeparator': u'\uF76E',
    'DiscretionaryParagraphSeparator': u'\uF76F',
    'Divide': u'\u00F7',
    'DotEqual': u'\u2250',
    'DotlessI': u'\u0131',
    'DotlessJ': u'\uF700',
    'DottedSquare': u'\uF751',
    'DoubleContourIntegral': u'\u222F',
    'DoubleDagger': u'\u2021',
    'DoubledGamma': u'\uF74A',
    'DoubleDownArrow': u'\u21D3',
    'DoubledPi': u'\uF749',
    'DoubleLeftArrow': u'\u21D0',
    'DoubleLeftRightArrow': u'\u21D4',
    'DoubleLeftTee': u'\u2AE4',
    'DoubleLongLeftArrow': u'\u27F8',
    'DoubleLongLeftRightArrow': u'\u27FA',
    'DoubleLongRightArrow': u'\u27F9',
    'DoublePrime': u'\u2033',
    'DoubleRightArrow': u'\u21D2',
    'DoubleRightTee': u'\u22A8',
    'DoubleStruckA': u'\uF6E6',
    'DoubleStruckB': u'\uF6E7',
    'DoubleStruckC': u'\uF6E8',
    'DoubleStruckCapitalA': u'\uF7A4',
    'DoubleStruckCapitalB': u'\uF7A5',
    'DoubleStruckCapitalC': u'\uF7A6',
    'DoubleStruckCapitalD': u'\uF7A7',
    'DoubleStruckCapitalE': u'\uF7A8',
    'DoubleStruckCapitalF': u'\uF7A9',
    'DoubleStruckCapitalG': u'\uF7AA',
    'DoubleStruckCapitalH': u'\uF7AB',
    'DoubleStruckCapitalI': u'\uF7AC',
    'DoubleStruckCapitalJ': u'\uF7AD',
    'DoubleStruckCapitalK': u'\uF7AE',
    'DoubleStruckCapitalL': u'\uF7AF',
    'DoubleStruckCapitalM': u'\uF7B0',
    'DoubleStruckCapitalN': u'\uF7B1',
    'DoubleStruckCapitalO': u'\uF7B2',
    'DoubleStruckCapitalP': u'\uF7B3',
    'DoubleStruckCapitalQ': u'\uF7B4',
    'DoubleStruckCapitalR': u'\uF7B5',
    'DoubleStruckCapitalS': u'\uF7B6',
    'DoubleStruckCapitalT': u'\uF7B7',
    'DoubleStruckCapitalU': u'\uF7B8',
    'DoubleStruckCapitalV': u'\uF7B9',
    'DoubleStruckCapitalW': u'\uF7BA',
    'DoubleStruckCapitalX': u'\uF7BB',
    'DoubleStruckCapitalY': u'\uF7BC',
    'DoubleStruckCapitalZ': u'\uF7BD',
    'DoubleStruckD': u'\uF6E9',
    'DoubleStruckE': u'\uF6EA',
    'DoubleStruckEight': u'\uF7E3',
    'DoubleStruckF': u'\uF6EB',
    'DoubleStruckFive': u'\uF7E0',
    'DoubleStruckFour': u'\uF7DF',
    'DoubleStruckG': u'\uF6EC',
    'DoubleStruckH': u'\uF6ED',
    'DoubleStruckI': u'\uF6EE',
    'DoubleStruckJ': u'\uF6EF',
    'DoubleStruckK': u'\uF6F0',
    'DoubleStruckL': u'\uF6F1',
    'DoubleStruckM': u'\uF6F2',
    'DoubleStruckN': u'\uF6F3',
    'DoubleStruckNine': u'\uF7E4',
    'DoubleStruckO': u'\uF6F4',
    'DoubleStruckOne': u'\uF7DC',
    'DoubleStruckP': u'\uF6F5',
    'DoubleStruckQ': u'\uF6F6',
    'DoubleStruckR': u'\uF6F7',
    'DoubleStruckS': u'\uF6F8',
    'DoubleStruckSeven': u'\uF7E2',
    'DoubleStruckSix': u'\uF7E1',
    'DoubleStruckT': u'\uF6F9',
    'DoubleStruckThree': u'\uF7DE',
    'DoubleStruckTwo': u'\uF7DD',
    'DoubleStruckU': u'\uF6FA',
    'DoubleStruckV': u'\uF6FB',
    'DoubleStruckW': u'\uF6FC',
    'DoubleStruckX': u'\uF6FD',
    'DoubleStruckY': u'\uF6FE',
    'DoubleStruckZ': u'\uF6FF',
    'DoubleStruckZero': u'\uF7DB',
    'DoubleUpArrow': u'\u21D1',
    'DoubleUpDownArrow': u'\u21D5',
    'DoubleVerticalBar': u'\u2225',
    'DownArrowBar': u'\u2913',
    'DownArrow': u'\u2193',
    'DownArrowUpArrow': u'\u21F5',
    'DownBreve': u'\uF755',
    'DownExclamation': u'\u00A1',
    'DownLeftRightVector': u'\u2950',
    'DownLeftTeeVector': u'\u295E',
    'DownLeftVector': u'\u21BD',
    'DownLeftVectorBar': u'\u2956',
    'DownPointer': u'\u25BE',
    'DownQuestion': u'\u00BF',
    'DownRightTeeVector': u'\u295F',
    'DownRightVector': u'\u21C1',
    'DownRightVectorBar': u'\u2957',
    'DownTeeArrow': u'\u21A7',
    'DownTee': u'\u22A4',
    'EAcute': u'\u00E9',
    'Earth': u'\u2641',
    'EBar': u'\u0113',
    'ECup': u'\u0115',
    'EDoubleDot': u'\u00EB',
    'EGrave': u'\u00E8',
    'EHacek': u'\u011B',
    'EHat': u'\u00EA',
    'EighthNote': u'\u266A',
    'Element': u'\u2208',
    'Ellipsis': u'\u2026',
    'EmptyCircle': u'\u25CB',
    'EmptyDiamond': u'\u25C7',
    'EmptyDownTriangle': u'\u25BD',
    'EmptyRectangle': u'\u25AF',
    'EmptySet': u'\u2205',
    'EmptySmallCircle': u'\u25E6',
    'EmptySmallSquare': u'\u25FB',
    'EmptySquare': u'\u25A1',
    'EmptyUpTriangle': u'\u25B3',
    'EmptyVerySmallSquare': u'\u25AB',
    'EnterKey': u'\uF7D4',
    'EntityEnd': u'\uF3B9',
    'EntityStart': u'\uF3B8',
    'Epsilon': u'\u03F5',
    'Equal': u'\uF431',
    'EqualTilde': u'\u2242',
    'Equilibrium': u'\u21CC',
    'Equivalent': u'\u29E6',
    'ErrorIndicator': u'\uF767',
    'EscapeKey': u'\uF769',
    'Eta': u'\u03B7',
    'Eth': u'\u00F0',
    'Euro': u'\u20AC',
    'Exists': u'\u2203',
    'ExponentialE': u'\uF74D',
    'FiLigature': u'\uFB01',
    'FilledCircle': u'\u25CF',
    'FilledDiamond': u'\u25C6',
    'FilledDownTriangle': u'\u25BC',
    'FilledLeftTriangle': u'\u25C0',
    'FilledRectangle': u'\u25AE',
    'FilledRightTriangle': u'\u25B6',
    'FilledSmallCircle': u'\uF750',
    'FilledSmallSquare': u'\u25FC',
    'FilledSquare': u'\u25A0',
    'FilledUpTriangle': u'\u25B2',
    'FilledVerySmallSquare': u'\u25AA',
    'FinalSigma': u'\u03C2',
    'FirstPage': u'\uF7FA',
    'FivePointedStar': u'\u2605',
    'Flat': u'\u266D',
    'FlLigature': u'\uFB02',
    'Florin': u'\u0192',
    'ForAll': u'\u2200',
    'FormalA': u'\uF800',
    'FormalB': u'\uF801',
    'FormalC': u'\uF802',
    'FormalCapitalA': u'\uF81A',
    'FormalCapitalB': u'\uF81B',
    'FormalCapitalC': u'\uF81C',
    'FormalCapitalD': u'\uF81D',
    'FormalCapitalE': u'\uF81E',
    'FormalCapitalF': u'\uF81F',
    'FormalCapitalG': u'\uF820',
    'FormalCapitalH': u'\uF821',
    'FormalCapitalI': u'\uF822',
    'FormalCapitalJ': u'\uF823',
    'FormalCapitalK': u'\uF824',
    'FormalCapitalL': u'\uF825',
    'FormalCapitalM': u'\uF826',
    'FormalCapitalN': u'\uF827',
    'FormalCapitalO': u'\uF828',
    'FormalCapitalP': u'\uF829',
    'FormalCapitalQ': u'\uF82A',
    'FormalCapitalR': u'\uF82B',
    'FormalCapitalS': u'\uF82C',
    'FormalCapitalT': u'\uF82D',
    'FormalCapitalU': u'\uF82E',
    'FormalCapitalV': u'\uF82F',
    'FormalCapitalW': u'\uF830',
    'FormalCapitalX': u'\uF831',
    'FormalCapitalY': u'\uF832',
    'FormalCapitalZ': u'\uF833',
    'FormalD': u'\uF803',
    'FormalE': u'\uF804',
    'FormalF': u'\uF805',
    'FormalG': u'\uF806',
    'FormalH': u'\uF807',
    'FormalI': u'\uF808',
    'FormalJ': u'\uF809',
    'FormalK': u'\uF80A',
    'FormalL': u'\uF80B',
    'FormalM': u'\uF80C',
    'FormalN': u'\uF80D',
    'FormalO': u'\uF80E',
    'FormalP': u'\uF80F',
    'FormalQ': u'\uF810',
    'FormalR': u'\uF811',
    'FormalS': u'\uF812',
    'FormalT': u'\uF813',
    'FormalU': u'\uF814',
    'FormalV': u'\uF815',
    'FormalW': u'\uF816',
    'FormalX': u'\uF817',
    'FormalY': u'\uF818',
    'FormalZ': u'\uF819',
    'FreakedSmiley': u'\uF721',
    'Function': u'\uF4A1',
    'Gamma': u'\u03B3',
    'Gimel': u'\u2137',
    'GothicA': u'\uF6CC',
    'GothicB': u'\uF6CD',
    'GothicC': u'\uF6CE',
    'GothicCapitalA': u'\uF78A',
    'GothicCapitalB': u'\uF78B',
    'GothicCapitalC': u'\u212D',
    'GothicCapitalD': u'\uF78D',
    'GothicCapitalE': u'\uF78E',
    'GothicCapitalF': u'\uF78F',
    'GothicCapitalG': u'\uF790',
    'GothicCapitalH': u'\u210C',
    'GothicCapitalI': u'\u2111',
    'GothicCapitalJ': u'\uF793',
    'GothicCapitalK': u'\uF794',
    'GothicCapitalL': u'\uF795',
    'GothicCapitalM': u'\uF796',
    'GothicCapitalN': u'\uF797',
    'GothicCapitalO': u'\uF798',
    'GothicCapitalP': u'\uF799',
    'GothicCapitalQ': u'\uF79A',
    'GothicCapitalR': u'\u211C',
    'GothicCapitalS': u'\uF79C',
    'GothicCapitalT': u'\uF79D',
    'GothicCapitalU': u'\uF79E',
    'GothicCapitalV': u'\uF79F',
    'GothicCapitalW': u'\uF7A0',
    'GothicCapitalX': u'\uF7A1',
    'GothicCapitalY': u'\uF7A2',
    'GothicCapitalZ': u'\u2128',
    'GothicD': u'\uF6CF',
    'GothicE': u'\uF6D0',
    'GothicEight': u'\uF7ED',
    'GothicF': u'\uF6D1',
    'GothicFive': u'\uF7EA',
    'GothicFour': u'\uF7E9',
    'GothicG': u'\uF6D2',
    'GothicH': u'\uF6D3',
    'GothicI': u'\uF6D4',
    'GothicJ': u'\uF6D5',
    'GothicK': u'\uF6D6',
    'GothicL': u'\uF6D7',
    'GothicM': u'\uF6D8',
    'GothicN': u'\uF6D9',
    'GothicNine': u'\uF7EF',
    'GothicO': u'\uF6DA',
    'GothicOne': u'\uF7E6',
    'GothicP': u'\uF6DB',
    'GothicQ': u'\uF6DC',
    'GothicR': u'\uF6DD',
    'GothicS': u'\uF6DE',
    'GothicSeven': u'\uF7EC',
    'GothicSix': u'\uF7EB',
    'GothicT': u'\uF6DF',
    'GothicThree': u'\uF7E8',
    'GothicTwo': u'\uF7E7',
    'GothicU': u'\uF6E0',
    'GothicV': u'\uF6E1',
    'GothicW': u'\uF6E2',
    'GothicX': u'\uF6E3',
    'GothicY': u'\uF6E4',
    'GothicZ': u'\uF6E5',
    'GothicZero': u'\uF7E5',
    'GrayCircle': u'\uF753',
    'GraySquare': u'\uF752',
    'GreaterEqualLess': u'\u22DB',
    'GreaterEqual': u'\u2265',
    'GreaterFullEqual': u'\u2267',
    'GreaterGreater': u'\u226B',
    'GreaterLess': u'\u2277',
    'GreaterSlantEqual': u'\u2A7E',
    'GreaterTilde': u'\u2273',
    'Hacek': u'\u02C7',
    'HappySmiley': u'\u263A',
    'HBar': u'\u210F',
    'HeartSuit': u'\u2661',
    'HermitianConjugate': u'\uF3CE',
    'HorizontalLine': u'\u2500',
    'HumpDownHump': u'\u224E',
    'HumpEqual': u'\u224F',
    'Hyphen': u'\u2010',
    'IAcute': u'\u00ED',
    'ICup': u'\u012D',
    'IDoubleDot': u'\u00EF',
    'IGrave': u'\u00EC',
    'IHat': u'\u00EE',
    'ImaginaryI': u'\uF74E',
    'ImaginaryJ': u'\uF74F',
    'ImplicitPlus': u'\uF39E',
    'Implies': u'\uF523',
    'Infinity': u'\u221E',
    'Integral': u'\u222B',
    'Intersection': u'\u22C2',
    'InvisibleApplication': u'\uF76D',
    'InvisibleComma': u'\uF765',
    'InvisiblePostfixScriptBase': u'\uF3B4',
    'InvisiblePrefixScriptBase': u'\uF3B3',
    'InvisibleSpace': u'\uF360',
    'InvisibleTimes': u'\u2062',
    'Iota': u'\u03B9',
    'Jupiter': u'\u2643',
    'Kappa': u'\u03BA',
    'KernelIcon': u'\uF756',
    'Koppa': u'\u03DF',
    'Lambda': u'\u03BB',
    'LastPage': u'\uF7FB',
    'LeftAngleBracket': u'\u2329',
    'LeftArrowBar': u'\u21E4',
    'LeftArrow': u'\u2190',
    'LeftArrowRightArrow': u'\u21C6',
    'LeftBracketingBar': u'\uF603',
    'LeftCeiling': u'\u2308',
    'LeftDoubleBracket': u'\u301A',
    'LeftDoubleBracketingBar': u'\uF605',
    'LeftDownTeeVector': u'\u2961',
    'LeftDownVectorBar': u'\u2959',
    'LeftDownVector': u'\u21C3',
    'LeftFloor': u'\u230A',
    'LeftGuillemet': u'\u00AB',
    'LeftModified': u'\uF76B',
    'LeftPointer': u'\u25C2',
    'LeftRightArrow': u'\u2194',
    'LeftRightVector': u'\u294E',
    'LeftSkeleton': u'\uF761',
    'LeftTee': u'\u22A3',
    'LeftTeeArrow': u'\u21A4',
    'LeftTeeVector': u'\u295A',
    'LeftTriangle': u'\u22B2',
    'LeftTriangleBar': u'\u29CF',
    'LeftTriangleEqual': u'\u22B4',
    'LeftUpDownVector': u'\u2951',
    'LeftUpTeeVector': u'\u2960',
    'LeftUpVector': u'\u21BF',
    'LeftUpVectorBar': u'\u2958',
    'LeftVector': u'\u21BC',
    'LeftVectorBar': u'\u2952',
    'LessEqual': u'\u2264',
    'LessEqualGreater': u'\u22DA',
    'LessFullEqual': u'\u2266',
    'LessGreater': u'\u2276',
    'LessLess': u'\u226A',
    'LessSlantEqual': u'\u2A7D',
    'LessTilde': u'\u2272',
    'LetterSpace': u'\uF754',
    'LightBulb': u'\uF723',
    'LongDash': u'\u2014',
    'LongEqual': u'\uF7D9',
    'LongLeftArrow': u'\u27F5',
    'LongLeftRightArrow': u'\u27F7',
    'LongRightArrow': u'\u27F6',
    'LowerLeftArrow': u'\u2199',
    'LowerRightArrow': u'\u2198',
    'LSlash': u'\u0142',
    'Mars': u'\u2642',
    'MathematicaIcon': u'\uF757',
    'MeasuredAngle': u'\u2221',
    'MediumSpace': u'\u205F',
    'Mercury': u'\u263F',
    'Mho': u'\u2127',
    'Micro': u'\u00B5',
    'MinusPlus': u'\u2213',
    'Mu': u'\u03BC',
    'Nand': u'\u22BC',
    'Natural': u'\u266E',
    'NegativeMediumSpace': u'\uF383',
    'NegativeThickSpace': u'\uF384',
    'NegativeThinSpace': u'\uF382',
    'NegativeVeryThinSpace': u'\uF380',
    'Neptune': u'\u2646',
    'NestedGreaterGreater': u'\u2AA2',
    'NestedLessLess': u'\u2AA1',
    'NeutralSmiley': u'\uF722',
    'NHacek': u'\u0148',
    'NoBreak': u'\u2060',
    'NonBreakingSpace': u'\u00A0',
    'Nor': u'\u22BD',
    'NotCongruent': u'\u2262',
    'NotCupCap': u'\u226D',
    'NotDoubleVerticalBar': u'\u2226',
    'NotElement': u'\u2209',
    'NotEqual': u'\u2260',
    'NotEqualTilde': u'\uF400',
    'NotExists': u'\u2204',
    'NotGreater': u'\u226F',
    'NotGreaterEqual': u'\u2271',
    'NotGreaterFullEqual': u'\u2269',
    'NotGreaterGreater': u'\uF427',
    'NotGreaterLess': u'\u2279',
    'NotGreaterSlantEqual': u'\uF429',
    'NotGreaterTilde': u'\u2275',
    'NotHumpDownHump': u'\uF402',
    'NotHumpEqual': u'\uF401',
    'NotLeftTriangle': u'\u22EA',
    'NotLeftTriangleBar': u'\uF412',
    'NotLeftTriangleEqual': u'\u22EC',
    'NotLessEqual': u'\u2270',
    'NotLessFullEqual': u'\u2268',
    'NotLessGreater': u'\u2278',
    'NotLess': u'\u226E',
    'NotLessLess': u'\uF422',
    'NotLessSlantEqual': u'\uF424',
    'NotLessTilde': u'\u2274',
    'Not': u'\u00AC',
    'NotNestedGreaterGreater': u'\uF428',
    'NotNestedLessLess': u'\uF423',
    'NotPrecedes': u'\u2280',
    'NotPrecedesEqual': u'\uF42B',
    'NotPrecedesSlantEqual': u'\u22E0',
    'NotPrecedesTilde': u'\u22E8',
    'NotReverseElement': u'\u220C',
    'NotRightTriangle': u'\u22EB',
    'NotRightTriangleBar': u'\uF413',
    'NotRightTriangleEqual': u'\u22ED',
    'NotSquareSubset': u'\uF42E',
    'NotSquareSubsetEqual': u'\u22E2',
    'NotSquareSuperset': u'\uF42F',
    'NotSquareSupersetEqual': u'\u22E3',
    'NotSubset': u'\u2284',
    'NotSubsetEqual': u'\u2288',
    'NotSucceeds': u'\u2281',
    'NotSucceedsEqual': u'\uF42D',
    'NotSucceedsSlantEqual': u'\u22E1',
    'NotSucceedsTilde': u'\u22E9',
    'NotSuperset': u'\u2285',
    'NotSupersetEqual': u'\u2289',
    'NotTilde': u'\u2241',
    'NotTildeEqual': u'\u2244',
    'NotTildeFullEqual': u'\u2247',
    'NotTildeTilde': u'\u2249',
    'NotVerticalBar': u'\u2224',
    'NTilde': u'\u00F1',
    'Nu': u'\u03BD',
    'Null': u'\uF3A0',
    'NumberSign': u'\uF724',
    'OAcute': u'\u00F3',
    'ODoubleAcute': u'\u0151',
    'ODoubleDot': u'\u00F6',
    'OE': u'\u0153',
    'OGrave': u'\u00F2',
    'OHat': u'\u00F4',
    'Omega': u'\u03C9',
    'Omicron': u'\u03BF',
    'OpenCurlyDoubleQuote': u'\u201C',
    'OpenCurlyQuote': u'\u2018',
    'OptionKey': u'\uF7D2',
    'Or': u'\u2228',
    'OSlash': u'\u00F8',
    'OTilde': u'\u00F5',
    'OverBrace': u'\uFE37',
    'OverBracket': u'\u23B4',
    'OverParenthesis': u'\uFE35',
    'Paragraph': u'\u00B6',
    'PartialD': u'\u2202',
    'Phi': u'\u03D5',
    'Pi': u'\u03C0',
    'Piecewise': u'\uF361',
    'Placeholder': u'\uF528',
    'PlusMinus': u'\u00B1',
    'Pluto': u'\u2647',
    'Precedes': u'\u227A',
    'PrecedesEqual': u'\u2AAF',
    'PrecedesSlantEqual': u'\u227C',
    'PrecedesTilde': u'\u227E',
    'Prime': u'\u2032',
    'Product': u'\u220F',
    'Proportion': u'\u2237',
    'Proportional': u'\u221D',
    'Psi': u'\u03C8',
    'QuarterNote': u'\u2669',
    'RawAmpersand': u'\u0026',
    'RawAt': u'\u0040',
    'RawBackquote': u'\u0060',
    'RawBackslash': u'\u005C',
    'RawColon': u'\u003A',
    'RawComma': u'\u002C',
    'RawDash': u'\u002D',
    'RawDollar': u'\u0024',
    'RawDot': u'\u002E',
    'RawDoubleQuote': u'\u0022',
    'RawEqual': u'\u003D',
    'RawEscape': u'\u001B',
    'RawExclamation': u'\u0021',
    'RawGreater': u'\u003E',
    'RawLeftBrace': u'\u007B',
    'RawLeftBracket': u'\u005B',
    'RawLeftParenthesis': u'\u0028',
    'RawLess': u'\u003C',
    'RawNumberSign': u'\u0023',
    'RawPercent': u'\u0025',
    'RawPlus': u'\u002B',
    'RawQuestion': u'\u003F',
    'RawQuote': u'\u0027',
    'RawRightBrace': u'\u007D',
    'RawRightBracket': u'\u005D',
    'RawRightParenthesis': u'\u0029',
    'RawSemicolon': u'\u003B',
    'RawSlash': u'\u002F',
    'RawSpace': u'\u0020',
    'RawStar': u'\u002A',
    'RawTab': u'\u0009',
    'RawTilde': u'\u007E',
    'RawUnderscore': u'\u005F',
    'RawVerticalBar': u'\u007C',
    'RawWedge': u'\u005E',
    'RegisteredTrademark': u'\u00AE',
    'ReturnIndicator': u'\u21B5',
    'ReturnKey': u'\uF766',
    'ReverseDoublePrime': u'\u2036',
    'ReverseElement': u'\u220B',
    'ReverseEquilibrium': u'\u21CB',
    'ReversePrime': u'\u2035',
    'ReverseUpEquilibrium': u'\u296F',
    'RHacek': u'\u0159',
    'Rho': u'\u03C1',
    'RightAngle': u'\u221F',
    'RightAngleBracket': u'\u232A',
    'RightArrow': u'\u2192',
    'RightArrowBar': u'\u21E5',
    'RightArrowLeftArrow': u'\u21C4',
    'RightBracketingBar': u'\uF604',
    'RightCeiling': u'\u2309',
    'RightDoubleBracket': u'\u301B',
    'RightDoubleBracketingBar': u'\uF606',
    'RightDownTeeVector': u'\u295D',
    'RightDownVector': u'\u21C2',
    'RightDownVectorBar': u'\u2955',
    'RightFloor': u'\u230B',
    'RightGuillemet': u'\u00BB',
    'RightModified': u'\uF76C',
    'RightPointer': u'\u25B8',
    'RightSkeleton': u'\uF762',
    'RightTee': u'\u22A2',
    'RightTeeArrow': u'\u21A6',
    'RightTeeVector': u'\u295B',
    'RightTriangle': u'\u22B3',
    'RightTriangleBar': u'\u29D0',
    'RightTriangleEqual': u'\u22B5',
    'RightUpDownVector': u'\u294F',
    'RightUpTeeVector': u'\u295C',
    'RightUpVector': u'\u21BE',
    'RightUpVectorBar': u'\u2954',
    'RightVector': u'\u21C0',
    'RightVectorBar': u'\u2953',
    'RoundImplies': u'\u2970',
    'RoundSpaceIndicator': u'\uF3B2',
    'Rule': u'\uF522',
    'RuleDelayed': u'\uF51F',
    'SadSmiley': u'\u2639',
    'Sampi': u'\u03E0',
    'Saturn': u'\u2644',
    'ScriptA': u'\uF6B2',
    'ScriptB': u'\uF6B3',
    'ScriptC': u'\uF6B4',
    'ScriptCapitalA': u'\uF770',
    'ScriptCapitalB': u'\u212C',
    'ScriptCapitalC': u'\uF772',
    'ScriptCapitalD': u'\uF773',
    'ScriptCapitalE': u'\u2130',
    'ScriptCapitalF': u'\u2131',
    'ScriptCapitalG': u'\uF776',
    'ScriptCapitalH': u'\u210B',
    'ScriptCapitalI': u'\u2110',
    'ScriptCapitalJ': u'\uF779',
    'ScriptCapitalK': u'\uF77A',
    'ScriptCapitalL': u'\u2112',
    'ScriptCapitalM': u'\u2133',
    'ScriptCapitalN': u'\uF77D',
    'ScriptCapitalO': u'\uF77E',
    'ScriptCapitalP': u'\u2118',
    'ScriptCapitalQ': u'\uF780',
    'ScriptCapitalR': u'\u211B',
    'ScriptCapitalS': u'\uF782',
    'ScriptCapitalT': u'\uF783',
    'ScriptCapitalU': u'\uF784',
    'ScriptCapitalV': u'\uF785',
    'ScriptCapitalW': u'\uF786',
    'ScriptCapitalX': u'\uF787',
    'ScriptCapitalY': u'\uF788',
    'ScriptCapitalZ': u'\uF789',
    'ScriptD': u'\uF6B5',
    'ScriptDotlessI': u'\uF730',
    'ScriptDotlessJ': u'\uF731',
    'ScriptE': u'\u212F',
    'ScriptEight': u'\uF7F8',
    'ScriptF': u'\uF6B7',
    'ScriptFive': u'\uF7F5',
    'ScriptFour': u'\uF7F4',
    'ScriptG': u'\u210A',
    'ScriptH': u'\uF6B9',
    'ScriptI': u'\uF6BA',
    'ScriptJ': u'\uF6BB',
    'ScriptK': u'\uF6BC',
    'ScriptL': u'\u2113',
    'ScriptM': u'\uF6BE',
    'ScriptN': u'\uF6BF',
    'ScriptNine': u'\uF7F9',
    'ScriptO': u'\u2134',
    'ScriptOne': u'\uF7F1',
    'ScriptP': u'\uF6C1',
    'ScriptQ': u'\uF6C2',
    'ScriptR': u'\uF6C3',
    'ScriptS': u'\uF6C4',
    'ScriptSeven': u'\uF7F7',
    'ScriptSix': u'\uF7F6',
    'ScriptT': u'\uF6C5',
    'ScriptThree': u'\uF7F3',
    'ScriptTwo': u'\uF7F2',
    'ScriptU': u'\uF6C6',
    'ScriptV': u'\uF6C7',
    'ScriptW': u'\uF6C8',
    'ScriptX': u'\uF6C9',
    'ScriptY': u'\uF6CA',
    'ScriptZ': u'\uF6CB',
    'ScriptZero': u'\uF7F0',
    'Section': u'\u00A7',
    'SelectionPlaceholder': u'\uF527',
    'SHacek': u'\u0161',
    'Sharp': u'\u266F',
    'ShortLeftArrow': u'\uF526',
    'ShortRightArrow': u'\uF525',
    'Sigma': u'\u03C3',
    'SixPointedStar': u'\u2736',
    'SkeletonIndicator': u'\u2043',
    'SmallCircle': u'\u2218',
    'SpaceIndicator': u'\u2423',
    'SpaceKey': u'\uF7BF',
    'SpadeSuit': u'\u2660',
    'SpanFromAbove': u'\uF3BB',
    'SpanFromBoth': u'\uF3BC',
    'SpanFromLeft': u'\uF3BA',
    'SphericalAngle': u'\u2222',
    'Sqrt': u'\u221A',
    'Square': u'\uF520',
    'SquareIntersection': u'\u2293',
    'SquareSubset': u'\u228F',
    'SquareSubsetEqual': u'\u2291',
    'SquareSuperset': u'\u2290',
    'SquareSupersetEqual': u'\u2292',
    'SquareUnion': u'\u2294',
    'Star': u'\u22C6',
    'Sterling': u'\u00A3',
    'Stigma': u'\u03DB',
    'Subset': u'\u2282',
    'SubsetEqual': u'\u2286',
    'Succeeds': u'\u227B',
    'SucceedsEqual': u'\u2AB0',
    'SucceedsSlantEqual': u'\u227D',
    'SucceedsTilde': u'\u227F',
    'SuchThat': u'\u220D',
    'Sum': u'\u2211',
    'Superset': u'\u2283',
    'SupersetEqual': u'\u2287',
    'SystemEnterKey': u'\uF75F',
    'SZ': u'\u00DF',
    'TabKey': u'\uF7BE',
    'Tau': u'\u03C4',
    'THacek': u'\u0165',
    'Therefore': u'\u2234',
    'Theta': u'\u03B8',
    'ThickSpace': u'\u2005',
    'ThinSpace': u'\u2009',
    'Thorn': u'\u00FE',
    'Tilde': u'\u223C',
    'TildeEqual': u'\u2243',
    'TildeFullEqual': u'\u2245',
    'TildeTilde': u'\u2248',
    'Times': u'\u00D7',
    'Trademark': u'\u2122',
    'Transpose': u'\uF3C7',
    'UAcute': u'\u00FA',
    'UDoubleAcute': u'\u0171',
    'UDoubleDot': u'\u00FC',
    'UGrave': u'\u00F9',
    'UHat': u'\u00FB',
    'UnderBrace': u'\uFE38',
    'UnderBracket': u'\u23B5',
    'UnderParenthesis': u'\uFE36',
    'Union': u'\u22C3',
    'UnionPlus': u'\u228E',
    'UpArrow': u'\u2191',
    'UpArrowBar': u'\u2912',
    'UpArrowDownArrow': u'\u21C5',
    'UpDownArrow': u'\u2195',
    'UpEquilibrium': u'\u296E',
    'UpperLeftArrow': u'\u2196',
    'UpperRightArrow': u'\u2197',
    'UpPointer': u'\u25B4',
    'Upsilon': u'\u03C5',
    'UpTee': u'\u22A5',
    'UpTeeArrow': u'\u21A5',
    'Uranus': u'\u2645',
    'URing': u'\u016F',
    'Vee': u'\u22C1',
    'Venus': u'\u2640',
    'VerticalBar': u'\u2223',
    'VerticalEllipsis': u'\u22EE',
    'VerticalLine': u'\u2502',
    'VerticalSeparator': u'\uF432',
    'VerticalTilde': u'\u2240',
    'VeryThinSpace': u'\u200A',
    'WarningSign': u'\uF725',
    'WatchIcon': u'\u231A',
    'Wedge': u'\u22C0',
    'WeierstrassP': u'\u2118',
    'WhiteBishop': u'\u2657',
    'WhiteKing': u'\u2654',
    'WhiteKnight': u'\u2658',
    'WhitePawn': u'\u2659',
    'WhiteQueen': u'\u2655',
    'WhiteRook': u'\u2656',
    'Wolf': u'\uF720',
    'Xi': u'\u03BE',
    'Xnor': u'\uF4A2',
    'Xor': u'\u22BB',
    'YAcute': u'\u00FD',
    'YDoubleDot': u'\u00FF',
    'Yen': u'\u00A5',
    'Zeta': u'\u03B6',
    'ZHacek': u'\u017E',
}

aliased_characters = {
    u"a'": u'\u00E1',
    u'a-': u'\u0101',
    u'au': u'\u0103',
    u'a"': u'\u00E4',
    u'ae': u'\u00E6',
    u'a`': u'\u00E0',
    u'a^': u'\u00E2',
    u'al': u'\u2135',
    u'esc': u'\uF768',
    u'am': u'\uF760',
    u'a': u'\u03B1',
    u'alpha': u'\u03B1',
    u'alt': u'\uF7D1',
    u'&&': u'\u2227',
    u'and': u'\u2227',
    u'Ang': u'\u212B',
    u'ao': u'\u00E5',
    u'a~': u'\u00E3',
    u'\\': u'\u2216',
    u'be': u'\u2136',
    u'b': u'\u03B2',
    u'beta': u'\u03B2',
    u'bv': u'\u02D8',
    u'bu': u'\u2022',
    u"c'": u'\u0107',
    u"A'": u'\u00C1',
    u'A-': u'\u0100',
    u'Au': u'\u0102',
    u'A"': u'\u00C4',
    u'AE': u'\u00C6',
    u'A`': u'\u00C0',
    u'A^': u'\u00C2',
    u'A': u'\u0391',
    u'Alpha': u'\u0391',
    u'Ao': u'\u00C5',
    u'A~': u'\u00C3',
    u'B': u'\u0392',
    u'Beta': u'\u0392',
    u"C'": u'\u0106',
    u'C,': u'\u00C7',
    u'Cv': u'\u010C',
    u'Ch': u'\u03A7',
    u'Chi': u'\u03A7',
    u'C': u'\u03A7',
    u'D': u'\u0394',
    u'Delta': u'\u0394',
    u'Dv': u'\u010E',
    u'DD': u'\uF74B',
    u'Di': u'\u03DC',
    u'Digamma': u'\u03DC',
    u"E'": u'\u00C9',
    u'E-': u'\u0112',
    u'Eu': u'\u0114',
    u'E"': u'\u00CB',
    u'E`': u'\u00C8',
    u'Ev': u'\u011A',
    u'E^': u'\u00CA',
    u'E': u'\u0395',
    u'Epsilon': u'\u0395',
    u'Et': u'\u0397',
    u'Eta': u'\u0397',
    u'H': u'\u0397',
    u'D-': u'\u00D0',
    u'G': u'\u0393',
    u'Gamma': u'\u0393',
    u"I'": u'\u00CD',
    u'Iu': u'\u012C',
    u'I"': u'\u00CF',
    u'I`': u'\u00CC',
    u'I^': u'\u00CE',
    u'I': u'\u0399',
    u'Iota': u'\u0399',
    u'K': u'\u039A',
    u'Kappa': u'\u039A',
    u'Ko': u'\u03DE',
    u'Koppa': u'\u03DE',
    u'L': u'\u039B',
    u'Lambda': u'\u039B',
    u'L/': u'\u0141',
    u'M': u'\u039C',
    u'Mu': u'\u039C',
    u'Nv': u'\u0147',
    u'N~': u'\u00D1',
    u'N': u'\u039D',
    u'Nu': u'\u039D',
    u"O'": u'\u00D3',
    u"O''": u'\u0150',
    u'O"': u'\u00D6',
    u'OE': u'\u0152',
    u'O`': u'\u00D2',
    u'O^': u'\u00D4',
    u'O': u'\u03A9',
    u'Omega': u'\u03A9',
    u'W': u'\u03A9',
    u'Om': u'\u039F',
    u'Omicron': u'\u039F',
    u'O/': u'\u00D8',
    u'O~': u'\u00D5',
    u'Ph': u'\u03A6',
    u'Phi': u'\u03A6',
    u'F': u'\u03A6',
    u'P': u'\u03A0',
    u'Pi': u'\u03A0',
    u'Ps': u'\u03A8',
    u'Psi': u'\u03A8',
    u'Y': u'\u03A8',
    u'Rv': u'\u0158',
    u'R': u'\u03A1',
    u'Rho': u'\u03A1',
    u'Sa': u'\u03E0',
    u'Sampi': u'\u03E0',
    u'Sv': u'\u0160',
    u'S': u'\u03A3',
    u'Sigma': u'\u03A3',
    u'T': u'\u03A4',
    u'Tau': u'\u03A4',
    u'Tv': u'\u0164',
    u'Th': u'\u0398',
    u'Theta': u'\u0398',
    u'Q': u'\u0398',
    u'Thn': u'\u00DE',
    u"U'": u'\u00DA',
    u"U''": u'\u0170',
    u'U"': u'\u00DC',
    u'U`': u'\u00D9',
    u'U^': u'\u00DB',
    u'U': u'\u03A5',
    u'Upsilon': u'\u03A5',
    u'Uo': u'\u016E',
    u'X': u'\u039E',
    u'Xi': u'\u039E',
    u"Y'": u'\u00DD',
    u'Z': u'\u0396',
    u'Zeta': u'\u0396',
    u'Zv': u'\u017D',
    u'c,': u'\u00E7',
    u'cd': u'\u00B8',
    u'.': u'\u00B7',
    u'cent': u'\u00A2',
    u'cv': u'\u010D',
    u'ch': u'\u03C7',
    u'chi': u'\u03C7',
    u'c': u'\u03C7',
    u'c.': u'\u2299',
    u'c-': u'\u2296',
    u'c+': u'\u2295',
    u'c*': u'\u2297',
    u'ccint': u'\u2232',
    u'cl': u'\u2318',
    u':': u'\u2236',
    u'cmd': u'\uF76A',
    u'===': u'\u2261',
    u'co': u'\uF3C8',
    u'conj': u'\uF3C8',
    u'ct': u'\uF3C9',
    u'cont': u'\uF3B1',
    u'cint': u'\u222E',
    u'ctrl': u'\uF763',
    u'coprod': u'\u2210',
    u'cccint': u'\u2233',
    u'cross': u'\uF4A0',
    u'cU': u'\u03D2',
    u'cUpsilon': u'\u03D2',
    u'ce': u'\u03B5',
    u'cepsilon': u'\u03B5',
    u'ck': u'\u03F0',
    u'ckappa': u'\u03F0',
    u'j': u'\u03C6',
    u'cph': u'\u03C6',
    u'cphi': u'\u03C6',
    u'cp': u'\u03D6',
    u'cpi': u'\u03D6',
    u'cr': u'\u03F1',
    u'crho': u'\u03F1',
    u'cq': u'\u03D1',
    u'cth': u'\u03D1',
    u'ctheta': u'\u03D1',
    u'dg': u'\u2020',
    u'da': u'\u2138',
    u'-': u'\u2013',
    u'deg': u'\u00B0',
    u' del': u'\uF7D0',
    u'del': u'\u2207',
    u'd': u'\u03B4',
    u'delta': u'\u03B4',
    u'dv': u'\u010F',
    u'dia': u'\u22C4',
    u'diffd': u'\u2206',
    u'dd': u'\uF74C',
    u'di': u'\u03DD',
    u'digamma': u'\u03DD',
    u'dratio': u'\uF4A4',
    u'shift': u'\uF4A3',
    u'dhy': u'\u00AD',
    u'dlsep': u'\uF76E',
    u'dpsep': u'\uF76F',
    u'div': u'\u00F7',
    u'.=': u'\u2250',
    u'ddg': u'\u2021',
    u'gg': u'\uF74A',
    u'pp': u'\uF749',
    u' <=': u'\u21D0',
    u'<=>': u'\u21D4',
    u'<==': u'\u27F8',
    u'<==>': u'\u27FA',
    u'==>': u'\u27F9',
    u"''": u'\u2033',
    u' =>': u'\u21D2',
    u'dsa': u'\uF6E6',
    u'dsb': u'\uF6E7',
    u'dsc': u'\uF6E8',
    u'dsA': u'\uF7A4',
    u'dsB': u'\uF7A5',
    u'dsC': u'\uF7A6',
    u'dsD': u'\uF7A7',
    u'dsE': u'\uF7A8',
    u'dsF': u'\uF7A9',
    u'dsG': u'\uF7AA',
    u'dsH': u'\uF7AB',
    u'dsI': u'\uF7AC',
    u'dsJ': u'\uF7AD',
    u'dsK': u'\uF7AE',
    u'dsL': u'\uF7AF',
    u'dsM': u'\uF7B0',
    u'dsN': u'\uF7B1',
    u'dsO': u'\uF7B2',
    u'dsP': u'\uF7B3',
    u'dsQ': u'\uF7B4',
    u'dsR': u'\uF7B5',
    u'dsS': u'\uF7B6',
    u'dsT': u'\uF7B7',
    u'dsU': u'\uF7B8',
    u'dsV': u'\uF7B9',
    u'dsW': u'\uF7BA',
    u'dsX': u'\uF7BB',
    u'dsY': u'\uF7BC',
    u'dsZ': u'\uF7BD',
    u'dsd': u'\uF6E9',
    u'dse': u'\uF6EA',
    u'ds8': u'\uF7E3',
    u'dsf': u'\uF6EB',
    u'ds5': u'\uF7E0',
    u'ds4': u'\uF7DF',
    u'dsg': u'\uF6EC',
    u'dsh': u'\uF6ED',
    u'dsi': u'\uF6EE',
    u'dsj': u'\uF6EF',
    u'dsk': u'\uF6F0',
    u'dsl': u'\uF6F1',
    u'dsm': u'\uF6F2',
    u'dsn': u'\uF6F3',
    u'ds9': u'\uF7E4',
    u'dso': u'\uF6F4',
    u'ds1': u'\uF7DC',
    u'dsp': u'\uF6F5',
    u'dsq': u'\uF6F6',
    u'dsr': u'\uF6F7',
    u'dss': u'\uF6F8',
    u'ds7': u'\uF7E2',
    u'ds6': u'\uF7E1',
    u'dst': u'\uF6F9',
    u'ds3': u'\uF7DE',
    u'ds2': u'\uF7DD',
    u'dsu': u'\uF6FA',
    u'dsv': u'\uF6FB',
    u'dsw': u'\uF6FC',
    u'dsx': u'\uF6FD',
    u'dsy': u'\uF6FE',
    u'dsz': u'\uF6FF',
    u'ds0': u'\uF7DB',
    u' ||': u'\u2225',
    u'dbv': u'\uF755',
    u'd!': u'\u00A1',
    u'd?': u'\u00BF',
    u'dT': u'\u22A4',
    u"e'": u'\u00E9',
    u'e-': u'\u0113',
    u'eu': u'\u0115',
    u'e"': u'\u00EB',
    u'e`': u'\u00E8',
    u'ev': u'\u011B',
    u'e^': u'\u00EA',
    u'el': u'\u2208',
    u'elem': u'\u2208',
    u'...': u'\u2026',
    u'eci': u'\u25CB',
    u'es': u'\u2205',
    u'esci': u'\u25E6',
    u'essq': u'\u25FB',
    u'esq': u'\u25A1',
    u'ent': u'\uF7D4',
    u'e': u'\u03F5',
    u'epsilon': u'\u03F5',
    u'==': u'\uF431',
    u'=~': u'\u2242',
    u'equi': u'\u21CC',
    u'equiv': u'\u29E6',
    u' esc': u'\uF769',
    u'et': u'\u03B7',
    u'eta': u'\u03B7',
    u'h': u'\u03B7',
    u'd-': u'\u00F0',
    u'ex': u'\u2203',
    u'ee': u'\uF74D',
    u'fci': u'\u25CF',
    u'fsci': u'\uF750',
    u'fssq': u'\u25FC',
    u'fsq': u'\u25A0',
    u'fvssq': u'\u25AA',
    u'fs': u'\u03C2',
    u'*5': u'\u2605',
    u'fa': u'\u2200',
    u'$a': u'\uF800',
    u'$b': u'\uF801',
    u'$c': u'\uF802',
    u'$A': u'\uF81A',
    u'$B': u'\uF81B',
    u'$C': u'\uF81C',
    u'$D': u'\uF81D',
    u'$E': u'\uF81E',
    u'$F': u'\uF81F',
    u'$G': u'\uF820',
    u'$H': u'\uF821',
    u'$I': u'\uF822',
    u'$J': u'\uF823',
    u'$K': u'\uF824',
    u'$L': u'\uF825',
    u'$M': u'\uF826',
    u'$N': u'\uF827',
    u'$O': u'\uF828',
    u'$P': u'\uF829',
    u'$Q': u'\uF82A',
    u'$R': u'\uF82B',
    u'$S': u'\uF82C',
    u'$T': u'\uF82D',
    u'$U': u'\uF82E',
    u'$V': u'\uF82F',
    u'$W': u'\uF830',
    u'$X': u'\uF831',
    u'$Y': u'\uF832',
    u'$Z': u'\uF833',
    u'$d': u'\uF803',
    u'$e': u'\uF804',
    u'$f': u'\uF805',
    u'$g': u'\uF806',
    u'$h': u'\uF807',
    u'$i': u'\uF808',
    u'$j': u'\uF809',
    u'$k': u'\uF80A',
    u'$l': u'\uF80B',
    u'$m': u'\uF80C',
    u'$n': u'\uF80D',
    u'$o': u'\uF80E',
    u'$p': u'\uF80F',
    u'$q': u'\uF810',
    u'$r': u'\uF811',
    u'$s': u'\uF812',
    u'$t': u'\uF813',
    u'$u': u'\uF814',
    u'$v': u'\uF815',
    u'$w': u'\uF816',
    u'$x': u'\uF817',
    u'$y': u'\uF818',
    u'$z': u'\uF819',
    u':-@': u'\uF721',
    u'fn': u'\uF4A1',
    u'g': u'\u03B3',
    u'gamma': u'\u03B3',
    u'gi': u'\u2137',
    u'goa': u'\uF6CC',
    u'gob': u'\uF6CD',
    u'goc': u'\uF6CE',
    u'goA': u'\uF78A',
    u'goB': u'\uF78B',
    u'goC': u'\u212D',
    u'goD': u'\uF78D',
    u'goE': u'\uF78E',
    u'goF': u'\uF78F',
    u'goG': u'\uF790',
    u'goH': u'\u210C',
    u'goI': u'\u2111',
    u'goJ': u'\uF793',
    u'goK': u'\uF794',
    u'goL': u'\uF795',
    u'goM': u'\uF796',
    u'goN': u'\uF797',
    u'goO': u'\uF798',
    u'goP': u'\uF799',
    u'goQ': u'\uF79A',
    u'goR': u'\u211C',
    u'goS': u'\uF79C',
    u'goT': u'\uF79D',
    u'goU': u'\uF79E',
    u'goV': u'\uF79F',
    u'goW': u'\uF7A0',
    u'goX': u'\uF7A1',
    u'goY': u'\uF7A2',
    u'goZ': u'\u2128',
    u'god': u'\uF6CF',
    u'goe': u'\uF6D0',
    u'go8': u'\uF7ED',
    u'gof': u'\uF6D1',
    u'go5': u'\uF7EA',
    u'go4': u'\uF7E9',
    u'gog': u'\uF6D2',
    u'goh': u'\uF6D3',
    u'goi': u'\uF6D4',
    u'goj': u'\uF6D5',
    u'gok': u'\uF6D6',
    u'gol': u'\uF6D7',
    u'gom': u'\uF6D8',
    u'gon': u'\uF6D9',
    u'go9': u'\uF7EF',
    u'goo': u'\uF6DA',
    u'go1': u'\uF7E6',
    u'gop': u'\uF6DB',
    u'goq': u'\uF6DC',
    u'gor': u'\uF6DD',
    u'gos': u'\uF6DE',
    u'go7': u'\uF7EC',
    u'go6': u'\uF7EB',
    u'got': u'\uF6DF',
    u'go3': u'\uF7E8',
    u'go2': u'\uF7E7',
    u'gou': u'\uF6E0',
    u'gov': u'\uF6E1',
    u'gow': u'\uF6E2',
    u'gox': u'\uF6E3',
    u'goy': u'\uF6E4',
    u'goz': u'\uF6E5',
    u'go0': u'\uF7E5',
    u'gci': u'\uF753',
    u'gsq': u'\uF752',
    u'>=': u'\u2265',
    u'>/': u'\u2A7E',
    u'>~': u'\u2273',
    u'hck': u'\u02C7',
    u':)': u'\u263A',
    u':-)': u'\u263A',
    u'hb': u'\u210F',
    u'hc': u'\uF3CE',
    u'hline': u'\u2500',
    u'h=': u'\u224F',
    u"i'": u'\u00ED',
    u'iu': u'\u012D',
    u'i"': u'\u00EF',
    u'i`': u'\u00EC',
    u'i^': u'\u00EE',
    u'ii': u'\uF74E',
    u'jj': u'\uF74F',
    u'+': u'\uF39E',
    u'=>': u'\uF523',
    u'inf': u'\u221E',
    u'int': u'\u222B',
    u'inter': u'\u22C2',
    u'@': u'\uF76D',
    u',': u'\uF765',
    u'is': u'\uF360',
    u'i': u'\u03B9',
    u'iota': u'\u03B9',
    u'k': u'\u03BA',
    u'kappa': u'\u03BA',
    u'ko': u'\u03DF',
    u'koppa': u'\u03DF',
    u'l': u'\u03BB',
    u'lambda': u'\u03BB',
    u'<': u'\u2329',
    u'<-': u'\u2190',
    u'l|': u'\uF603',
    u'lc': u'\u2308',
    u'[[': u'\u301A',
    u'l||': u'\uF605',
    u'lf': u'\u230A',
    u'g<<': u'\u00AB',
    u'[': u'\uF76B',
    u'<->': u'\u2194',
    u'lT': u'\u22A3',
    u'<=': u'\u2264',
    u'</': u'\u2A7D',
    u'<~': u'\u2272',
    u'_': u'\uF754',
    u'ls': u'\uF754',
    u'--': u'\u2014',
    u'<--': u'\u27F5',
    u'<-->': u'\u27F7',
    u'-->': u'\u27F6',
    u'l/': u'\u0142',
    u'math': u'\uF757',
    u'   ': u'\u205F',
    u'mho': u'\u2127',
    u'mi': u'\u00B5',
    u'-+': u'\u2213',
    u'm': u'\u03BC',
    u'mu': u'\u03BC',
    u'nand': u'\u22BC',
    u'-   ': u'\uF383',
    u'-    ': u'\uF384',
    u'-  ': u'\uF382',
    u'- ': u'\uF380',
    u':-|': u'\uF722',
    u'nv': u'\u0148',
    u'nb': u'\u2060',
    u'nbs': u'\u00A0',
    u'nor': u'\u22BD',
    u'!===': u'\u2262',
    u'!||': u'\u2226',
    u'!el': u'\u2209',
    u'!elem': u'\u2209',
    u'!=': u'\u2260',
    u'!=~': u'\uF400',
    u'!ex': u'\u2204',
    u'!>': u'\u226F',
    u'!>=': u'\u2271',
    u'!>/': u'\uF429',
    u'!>~': u'\u2275',
    u'!h=': u'\uF401',
    u'!<=': u'\u2270',
    u'!<': u'\u226E',
    u'!</': u'\uF424',
    u'!<~': u'\u2274',
    u'!': u'\u00AC',
    u'not': u'\u00AC',
    u'!mem': u'\u220C',
    u'!sub': u'\u2284',
    u'!sub=': u'\u2288',
    u'!sup': u'\u2285',
    u'!sup=': u'\u2289',
    u'!~': u'\u2241',
    u'!~=': u'\u2244',
    u'!~==': u'\u2247',
    u'!~~': u'\u2249',
    u'!|': u'\u2224',
    u'n~': u'\u00F1',
    u'n': u'\u03BD',
    u'nu': u'\u03BD',
    u'null': u'\uF3A0',
    u"o'": u'\u00F3',
    u"o''": u'\u0151',
    u'o"': u'\u00F6',
    u'oe': u'\u0153',
    u'o`': u'\u00F2',
    u'o^': u'\u00F4',
    u'o': u'\u03C9',
    u'omega': u'\u03C9',
    u'w': u'\u03C9',
    u'om': u'\u03BF',
    u'omicron': u'\u03BF',
    u'opt': u'\uF7D2',
    u'||': u'\u2228',
    u'or': u'\u2228',
    u'o/': u'\u00F8',
    u'o~': u'\u00F5',
    u'o{': u'\uFE37',
    u'o[': u'\u23B4',
    u'o(': u'\uFE35',
    u'pd': u'\u2202',
    u'ph': u'\u03D5',
    u'phi': u'\u03D5',
    u'f': u'\u03D5',
    u'p': u'\u03C0',
    u'pi': u'\u03C0',
    u'pw': u'\uF361',
    u'pl': u'\uF528',
    u'+-': u'\u00B1',
    u"'": u'\u2032',
    u'prod': u'\u220F',
    u'prop': u'\u221D',
    u'ps': u'\u03C8',
    u'psi': u'\u03C8',
    u'y': u'\u03C8',
    u'rtm': u'\u00AE',
    u'ret': u'\u21B5',
    u' ret': u'\uF766',
    u'``': u'\u2036',
    u'mem': u'\u220B',
    u'`': u'\u2035',
    u'rv': u'\u0159',
    u'r': u'\u03C1',
    u'rho': u'\u03C1',
    u'>': u'\u232A',
    u' ->': u'\u2192',
    u'r|': u'\uF604',
    u'rc': u'\u2309',
    u']]': u'\u301B',
    u'r||': u'\uF606',
    u'rf': u'\u230B',
    u'g>>': u'\u00BB',
    u']': u'\uF76C',
    u'rT': u'\u22A2',
    u'vec': u'\u21C0',
    u'->': u'\uF522',
    u':>': u'\uF51F',
    u':-(': u'\u2639',
    u'sa': u'\u03E0',
    u'sampi': u'\u03E0',
    u'sca': u'\uF6B2',
    u'scb': u'\uF6B3',
    u'scc': u'\uF6B4',
    u'scA': u'\uF770',
    u'scB': u'\u212C',
    u'scC': u'\uF772',
    u'scD': u'\uF773',
    u'scE': u'\u2130',
    u'scF': u'\u2131',
    u'scG': u'\uF776',
    u'scH': u'\u210B',
    u'scI': u'\u2110',
    u'scJ': u'\uF779',
    u'scK': u'\uF77A',
    u'scL': u'\u2112',
    u'scM': u'\u2133',
    u'scN': u'\uF77D',
    u'scO': u'\uF77E',
    u'scP': u'\u2118',
    u'scQ': u'\uF780',
    u'scR': u'\u211B',
    u'scS': u'\uF782',
    u'scT': u'\uF783',
    u'scU': u'\uF784',
    u'scV': u'\uF785',
    u'scW': u'\uF786',
    u'scX': u'\uF787',
    u'scY': u'\uF788',
    u'scZ': u'\uF789',
    u'scd': u'\uF6B5',
    u'sce': u'\u212F',
    u'sc8': u'\uF7F8',
    u'scf': u'\uF6B7',
    u'sc5': u'\uF7F5',
    u'sc4': u'\uF7F4',
    u'scg': u'\u210A',
    u'sch': u'\uF6B9',
    u'sci': u'\uF6BA',
    u'scj': u'\uF6BB',
    u'sck': u'\uF6BC',
    u'scl': u'\u2113',
    u'scm': u'\uF6BE',
    u'scn': u'\uF6BF',
    u'sc9': u'\uF7F9',
    u'sco': u'\u2134',
    u'sc1': u'\uF7F1',
    u'scp': u'\uF6C1',
    u'scq': u'\uF6C2',
    u'scr': u'\uF6C3',
    u'scs': u'\uF6C4',
    u'sc7': u'\uF7F7',
    u'sc6': u'\uF7F6',
    u'sct': u'\uF6C5',
    u'sc3': u'\uF7F3',
    u'sc2': u'\uF7F2',
    u'scu': u'\uF6C6',
    u'scv': u'\uF6C7',
    u'scw': u'\uF6C8',
    u'scx': u'\uF6C9',
    u'scy': u'\uF6CA',
    u'scz': u'\uF6CB',
    u'sc0': u'\uF7F0',
    u'spl': u'\uF527',
    u'sv': u'\u0161',
    u's': u'\u03C3',
    u'sigma': u'\u03C3',
    u'*6': u'\u2736',
    u'sc': u'\u2218',
    u'space': u'\u2423',
    u'spc': u'\uF7BF',
    u'sqrt': u'\u221A',
    u'sq': u'\uF520',
    u'star': u'\u22C6',
    u'sti': u'\u03DB',
    u'stigma': u'\u03DB',
    u'sub': u'\u2282',
    u'sub=': u'\u2286',
    u'st': u'\u220D',
    u'sum': u'\u2211',
    u'sup': u'\u2283',
    u'sup=': u'\u2287',
    u'sz': u'\u00DF',
    u'ss': u'\u00DF',
    u'tab': u'\uF7BE',
    u't': u'\u03C4',
    u'tau': u'\u03C4',
    u'tv': u'\u0165',
    u'tf': u'\u2234',
    u'th': u'\u03B8',
    u'theta': u'\u03B8',
    u'q': u'\u03B8',
    u'    ': u'\u2005',
    u'  ': u'\u2009',
    u'thn': u'\u00FE',
    u'~': u'\u223C',
    u'~=': u'\u2243',
    u'~==': u'\u2245',
    u'~~': u'\u2248',
    u'*': u'\u00D7',
    u'tm': u'\u2122',
    u'tr': u'\uF3C7',
    u"u'": u'\u00FA',
    u"u''": u'\u0171',
    u'u"': u'\u00FC',
    u'u`': u'\u00F9',
    u'u^': u'\u00FB',
    u'u{': u'\uFE38',
    u'u[': u'\u23B5',
    u'u(': u'\uFE36',
    u'un': u'\u22C3',
    u'u': u'\u03C5',
    u'upsilon': u'\u03C5',
    u'uT': u'\u22A5',
    u'uo': u'\u016F',
    u'v': u'\u22C1',
    u' |': u'\u2223',
    u'vline': u'\u2502',
    u'|': u'\uF432',
    u' ': u'\u200A',
    u'^': u'\u22C0',
    u'wp': u'\u2118',
    u'wf': u'\uF720',
    u'wolf': u'\uF720',
    u'x': u'\u03BE',
    u'xi': u'\u03BE',
    u'xnor': u'\uF4A2',
    u'xor': u'\u22BB',
    u"y'": u'\u00FD',
    u'z': u'\u03B6',
    u'zeta': u'\u03B6',
    u'zv': u'\u017E',
}
